Rexistro de Usuario | CRTVG
Description: CRTVG - Compañía de Radio/Televisión de Galicia
Keywords: TVG, CRTVG, Radio Galega, television, radio, galicia, galiza, galega, agalega, acarta, video, audio, radio galega musica, son galicia radio, television de galicia, galicia television, carteleira, tempo, licitacion, deporte, visita do Papa, Bieito XVI, Benedicto XVI, 25 anos,

Usuario
Contrasinal
Recordar
Esqueceu o contrasinal?
Rexístrate

# CRTVG

xoves 11 de decembro

- Ingresa I
- Rexístrate

Buscador
Nome*
Apelidos*
Enderezo electrónico*
Data de nacemento*
Usuario*
Contrasinal*
Verificar contrasinal*
(*) Campo obrigatorio
Acepto as condicións de privacidade e de uso, e declaro ser maior de 14 anos de idade

Os datos que se faciliten a través deste formulario, serán incluídos nun ficheiro da Compañía de Radio - Televisión de Galicia e das súas sociedades TELEVISIÓN DE GALICIA, S.A. e RADIOTELEVISIÓN GALICIA, S.A. con domicilio en Bando - San Marcos, 15.820 de Santiago de Compostela (A Coruña) onde poderá exercitar os dereitos de acceso, rectificación, cancelación e oposición, dirixindo ao Departamento de Servizos Xurídicos solicitude asinada por escrito xunto cunha fotocopia do seu D.N.I. ou na dirección lopd@crtvg.es.

Mediante a incorporación voluntaria dos seus datos, autoriza o tratamento dos mesmos coa finalidade de levar a cabo o seu rexistro como usuario activo desta páxina web, facilitarlle o acceso aos recursos da mesma e enviarlle información sobre actividades, eventos, servizos e produtos da CRTVG e as súas sociedades, mediante correo ordinario ou medios electrónicos. No caso de que nos proporcione datos de terceiros, deberá informar aos interesados das advertencias anteriores, absténdose de incluílos de non obter o seu consentimento.